@@ -4,7 +4,9 @@
 pyplr.calibrate
 ===============
 
-Module to assist with calibrating the sphere.
+Module to assist with calibrating the sphere. 
+
+THIS MODULE IS BEING REFACTORED
 
 @author: jtm
 
@@ -23,7 +25,8 @@ import pandas as pd
 import matplotlib.pyplot as plt
 import seaborn as sns
 
-from pyplr.stlab import SpectraTuneLab, get_led_colors
+from pyplr.stlab import SpectraTuneLab
+from pyplr.stlabhelp import get_led_colors
 from pyplr.CIE import get_CIE_1924_photopic_vl, get_CIES026
 
 
@@ -37,7 +40,7 @@ class SpectraTuneLabSampler(SpectraTuneLab):
     def __init__(self,
                  password: str,
                  username: str = 'admin',
-                 identity: int = 1,
+                 default_address: int = 1023,
                  lighthub_ip: str = '192.168.7.2',
                  external: object = None) -> None:
         """Initialize class and subclass. See `pyplr.stlab.SpectraTuneLab` for
@@ -57,7 +60,7 @@ class SpectraTuneLabSampler(SpectraTuneLab):
 
         """
 
-        super().__init__(password, username, identity, lighthub_ip)
+        super().__init__(password, username, default_address, lighthub_ip)
         self.external = external
         self._ready_cache()
 
@@ -68,33 +71,39 @@ class SpectraTuneLabSampler(SpectraTuneLab):
             self.ex_spectra = []
             self.ex_info = []
 
-    def make_dfs(self, save_csv: bool = False) -> None:
+    def make_dfs(self, save_csv: bool = False,
+                 external_fname: str = None) -> None:
         """Turn cached data and info into pandas DataFrames.
 
         Parameters
         ----------
         save_csv : bool
             Optionally save to csv format in the current working directory.
+        external_fname : str
+            Prefix for filenames containing data from external spectrometer.
 
         Returns
         -------
         None.
 
         """
+        if external_fname is None:
+            external_fname = 'external'
+            
         self.stlab_spectra = pd.DataFrame(self.stlab_spectra)
         self.stlab_spectra.columns = pd.Int64Index(self.wlbins)
         self.stlab_info = pd.DataFrame(self.stlab_info)
-        if 'led' in self.stlab_info.columns:
-            self.stlab_spectra['led'] = self.stlab_info['led']
-            self.stlab_spectra['intensity'] = self.stlab_info['intensity']
+        if 'Primary' in self.stlab_info.columns:
+            self.stlab_spectra['Primary'] = self.stlab_info['Primary']
+            self.stlab_spectra['Setting'] = self.stlab_info['Setting']
 
         if self.external is not None:
             self.ex_spectra = pd.DataFrame(self.ex_spectra)
             self.ex_spectra.columns = self.external.wavelengths()
             self.ex_info = pd.DataFrame(self.ex_info)
-            if 'led' in self.ex_info.columns:
-                self.ex_spectra['led'] = self.ex_info['led']
-                self.ex_spectra['intensity'] = self.ex_info['intensity']
+            if 'Primary' in self.ex_info.columns:
+                self.ex_spectra['Primary'] = self.ex_info['Primary']
+                self.ex_spectra['Setting'] = self.ex_info['Setting']
 
         if save_csv:
             self.stlab_spectra.to_csv(
@@ -102,14 +111,15 @@ class SpectraTuneLabSampler(SpectraTuneLab):
             self.stlab_info.to_csv(
                 op.join(os.getcwd(), 'stlab_info.csv'), index=False)
             if self.external is not None:
-                self.ex_spectra.to_csv(
-                    op.join(os.getcwd(), 'external_spectra.csv'), index=False)
+                self.ex_spectra.to_csv(op.join(
+                    os.getcwd(), f'{external_fname}_spectra.csv'), index=False)
                 self.ex_info.to_csv(
-                    op.join(os.getcwd(), 'external_info.csv'), index=False)
+                    op.join(os.getcwd(), f'{external_fname}_info.csv'),
+                    index=False)
 
     def full_readout(self,
                      norm: bool = False,
-                     setting: dict = {}) -> Tuple(np.array, dict):
+                     setting: dict = {}) -> Tuple[np.array, dict]:
         """Get a full readout from STLAB.
 
         Parameters
@@ -204,7 +214,7 @@ class SpectraTuneLabSampler(SpectraTuneLab):
                 len(spectra), spectra))
         else:
             settings = [(l, i) for l in leds for i in intensities]
-            print('Sampling {} leds at the following intensities: {}'.format(
+            print('Sampling {} primaries at the following settings: {}'.format(
                 len(leds), intensities))
 
         # shuffle
@@ -215,10 +225,10 @@ class SpectraTuneLabSampler(SpectraTuneLab):
         for i, s in enumerate(settings):
             if not spectra:
                 led, intensity = s[0], s[1]
-                setting = {'led': led, 'intensity': intensity}
+                setting = {'Primary': led, 'Setting': intensity}
                 s = [0] * 10
                 s[led] = intensity
-                print('Measurement: {} / {}, LED: {}, intensity: {}'.format(
+                print('Measurement: {} / {}, Primary: {}, Setting: {}'.format(
                     i + 1, len(settings), led, intensity))
             else:
                 setting = {'intensities': s}
@@ -499,7 +509,7 @@ class CalibrationContext:
               match_led: int,
               match_led_intensity: int,
               target_led: int,
-              match_type: str = 'irrad') -> Tuple(float, int):
+              match_type: str = 'irrad') -> Tuple[float, int]:
         """Determine the appropriate intensity setting for `target_led` so that
         its output will match `match_led` at `match_led_intensity` with respect
         to `match_type`.
